=== modified file 'ivle/webapp/admin/projectservice.py'
--- ivle/webapp/admin/projectservice.py	2009-05-04 02:05:20 +0000
+++ ivle/webapp/admin/projectservice.py	2009-08-18 07:20:12 +0000
@@ -17,12 +17,13 @@
 
 # Author: Nick Chadwick
 
+import datetime
 import ivle.database
 from ivle.database import ProjectSet, Project, Subject, Semester, Offering
 
 from ivle.webapp.base.rest import (XHTMLRESTView, named_operation,
                                    require_permission)
-from ivle.webapp.errors import NotFound
+from ivle.webapp.errors import NotFound, BadRequest
 
 class ProjectSetRESTView(XHTMLRESTView):
     """Rest view for a projectset.
@@ -51,12 +52,16 @@
                  project.short_name)
 
     @named_operation('edit')
-    def add_project(self, req, name, short_name, synopsis):
+    def add_project(self, req, name, short_name, deadline, synopsis):
         """Add a Project to this ProjectSet"""
         new_project = Project()
         new_project.name = unicode(name)
         new_project.short_name = unicode(short_name)
         new_project.synopsis = unicode(synopsis)
+        try:
+            new_project.deadline = datetime.datetime.strptime(deadline, '%Y-%m-%d %H:%M:%S')
+        except ValueError:
+            raise BadRequest("deadline must be in YYYY-MM-DD HH:MM:ss")
         new_project.project_set = self.context
 
         req.store.add(new_project)

=== modified file 'ivle/webapp/admin/templates/projectset_fragment.html'
--- ivle/webapp/admin/templates/projectset_fragment.html	2009-05-04 05:04:23 +0000
+++ ivle/webapp/admin/templates/projectset_fragment.html	2009-08-18 08:51:49 +0000
@@ -31,6 +31,9 @@
           <label for="new_project_short_name_${projectset.id}">Short Name:</label>
           <input id="new_project_short_name_${projectset.id}" type="text" name="short_name" value="" />
           <br />
+          <label for="new_project_deadline_${projectset.id}">Deadline:</label>
+          <input id="new_project_deadline_${projectset.id}" type="text" name="deadline" value="YYYY-MM-DD HH:mm:ss" />
+          <br />
           <label for="new_project_syn_${projectset.id}">Synopsis:</label>
           <textarea id="new_project_syn_${projectset.id}" name="synopsis" rows="6"></textarea>
           <br />

=== added file 'userdb/migrations/20090814-01.sql'
--- userdb/migrations/20090814-01.sql	1970-01-01 00:00:00 +0000
+++ userdb/migrations/20090814-01.sql	2009-08-13 21:28:32 +0000
@@ -0,0 +1,5 @@
+BEGIN;
+
+ALTER TABLE project ALTER COLUMN deadline SET NOT NULL;
+
+COMMIT;

=== modified file 'userdb/users.sql'
--- userdb/users.sql	2009-04-07 03:34:59 +0000
+++ userdb/users.sql	2009-08-13 21:28:32 +0000
@@ -66,7 +66,7 @@
     synopsis    TEXT,
     url         TEXT,
     projectsetid  INTEGER REFERENCES project_set (projectsetid) NOT NULL,
-    deadline    TIMESTAMP
+    deadline    TIMESTAMP NOT NULL
 );
 
 CREATE OR REPLACE FUNCTION check_project_namespacing_insertupdate()

